@@ -3,6 +3,7 @@ use strict;
 
 use constant BillingAddressConflict                                   => "91701";
 use constant BillingAddressIdIsInvalid                                => "91702";
+use constant CannotUpdateCardUsingPaymentMethodNonce                  => "91735";
 use constant CardholderNameIsTooLong                                  => "81723";
 use constant CreditCardTypeIsNotAccepted                              => "81703";
 use constant CreditCardTypeIsNotAcceptedBySubscriptionMerchantAccount => "81718";
@@ -10,6 +11,7 @@ use constant CustomerIdIsInvalid                                      => "91705"
 use constant CustomerIdIsRequired                                     => "91704";
 use constant CvvIsInvalid                                             => "81707";
 use constant CvvIsRequired                                            => "81706";
+use constant CvvVerificationFailed                                    => "81736";
 use constant DuplicateCardExists                                      => "81724";
 use constant ExpirationDateConflict                                   => "91708";
 use constant ExpirationDateIsInvalid                                  => "81710";
@@ -23,7 +25,13 @@ use constant NumberIsInvalid                                          => "81715"
 use constant NumberIsRequired                                         => "81714";
 use constant NumberLengthIsInvalid                                    => "81716";
 use constant NumberMustBeTestNumber                                   => "81717";
+use constant PaymentMethodCannotForwardPaymentMethodType              => "93107";
 use constant PaymentMethodConflict                                    => "81725";
+use constant PaymentMethodNonceCardTypeIsNotAccepted                  => "91734";
+use constant PaymentMethodNonceConsumed                               => "91731";
+use constant PaymentMethodNonceLocked                                 => "91733";
+use constant PaymentMethodNonceUnknown                                => "91732";
+use constant PostalCodeVerificationFailed                             => "81737";
 use constant TokenFormatIsInvalid                                     => "91718";
 use constant TokenInvalid                                             => "91718";
 use constant TokenIsInUse                                             => "91719";
@@ -32,6 +40,7 @@ use constant TokenIsRequired                                          => "91722"
 use constant TokenIsTooLong                                           => "91720";
 use constant UpdateExistingTokenNotAllowed                            => "91729";
 use constant VerificationNotSupportedOnThisMerchantAccount            => "91730";
+use constant VerificationMerchantAccountIdIsInvalid                   => "91728";
 use constant VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted           => "91726";
 
 1;
